# AtomTools

Collection of atom manupulation tools

[![Build Status](https://travis-ci.org/atomse/atomtools.svg?branch=master)](https://travis-ci.org/atomse/atomtools)
![PyPI](https://img.shields.io/pypi/v/atomtools.svg)


## name

* randString
* get_atoms_name

## unit

unit module contains all unit transform function isncluding

* trans_length
* trans_abs_energy
* trans_energy
* trans_velocity


## geo

geo module contains all frequenctly used geometry functions

* get_atoms_name
* get_atoms_size


basic measurements

* get_distance
* get_angle
* get_dihedral


matrix measurements

* get_distance_matrix
* get_contact_matrix
* dist_change_matrix
* freq_dist_change_matrix
* get_rotation_matrix


coordination transformation

* cartesian_to_zmatrix
* cartesian_to_spherical
* spherical_to_cartesian
* input_standard_pos_transform



## file

file module process all file related with file


* get_file_content
* get_filename
* get_extension




## TODOS


